@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020-2022 Red Hat.
+ * Copyright (c) 2020-2022,2024 Red Hat.
  *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -24,7 +24,7 @@ static sds		DEFAULT_RESULTCOUNT;
 static unsigned int	resultcount;	/* converted resultcount_str */
 
 static void
-initRedisSearchBaton(redisSearchBaton *baton, redisSlots *slots,
+initKeysSearchBaton(keysSearchBaton *baton, keySlots *slots,
 		pmSearchSettings *settings, void *userdata)
 {
     initSeriesBatonMagic(baton, MAGIC_SEARCH);
@@ -37,10 +37,10 @@ initRedisSearchBaton(redisSearchBaton *baton, redisSlots *slots,
 }
 
 static void
-doneRedisSearchBaton(redisSearchBaton *baton)
+doneKeysSearchBaton(keysSearchBaton *baton)
 {
-    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "doneRedisSearchBaton");
-    memset(baton, 0, sizeof(redisSearchBaton));
+    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "doneKeysSearchBaton");
+    memset(baton, 0, sizeof(keysSearchBaton));
     free(baton);
 }
 
@@ -61,7 +61,7 @@ pmSearchTextTypeStr(pmSearchTextType type)
 }
 
 static sds
-redis_search_docid(const char *key, const char *type, const char *name)
+keys_search_docid(const char *key, const char *type, const char *name)
 {
     unsigned char	hash[20];
     sds			docid = sdsempty();
@@ -74,11 +74,11 @@ redis_search_docid(const char *key, const char *type, const char *name)
 
 
 /*
- * This issue isn't fixed in OSS version of RediSearch we are using, 
+ * This issue isn't fixed in version of search module we are using, 
  * https://github.com/RediSearch/RediSearch/issues/748
  */
 static int
-redis_search_is_stopword(sds s)
+keys_search_is_stopword(sds s)
 {
     size_t			i;
     static const char* const 	stopwords[] = {
@@ -95,7 +95,7 @@ redis_search_is_stopword(sds s)
 }
 
 /*
- * Tokenizes text by delimiters described here https://oss.redislabs.com/redisearch/Escaping.html +
+ * Tokenizes text by delimiters described in search module Escaping.html doc +
  * ('/' - this one giving troubles to prefix search),
  * omits tokens of length greated then *min_length* (0 = don't omit any), optionally prepends *prefix*
  * and appends *suffix* (NULL doesnt get prepended / appended), joins tokens by space back into new sds.
@@ -103,7 +103,7 @@ redis_search_is_stopword(sds s)
  * unfortunately, this doesnt seem to work when searching for indoms and buch of other inconsitencies
  */
 static sds
-redis_search_text_prep(sds s, int min_length, char *prefix, char *suffix)
+keys_search_text_prep(sds s, int min_length, char *prefix, char *suffix)
 {
     static const char	*delimiters = ",.<>{}[]\"\':;!@#$%^&*()-+=~/"; 
     size_t		len = sdslen(s);
@@ -133,7 +133,7 @@ redis_search_text_prep(sds s, int min_length, char *prefix, char *suffix)
 	size_t token_len = sdslen(tokens[i]);
 	if (min_length != 0 && token_len < min_length)
 	   continue;
-	if (redis_search_is_stopword(tokens[i]))
+	if (keys_search_is_stopword(tokens[i]))
 	   continue;
 	if (prefix == NULL && suffix == NULL)
 	    formatted_result = sdscatsds(formatted_result, tokens[i]);
@@ -172,20 +172,20 @@ redis_search_text_prep(sds s, int min_length, char *prefix, char *suffix)
 }
 
 static void
-redis_search_text_add_callback(
-	redisClusterAsyncContext *c, void *r, void *arg)
+keys_search_text_add_callback(
+	keyClusterAsyncContext *c, void *r, void *arg)
 {
     seriesLoadBaton	*baton = (seriesLoadBaton *)arg;
     seriesGetContext	*context = &baton->pmapi;
-    redisReply		*reply = r;
+    respReply		*reply = r;
 
     checkStatusReplyOK(baton->info, baton->userdata, c, reply,
 		"%s: %s", FT_ADD, "search text add");
-    doneSeriesGetContext(context, "redis_search_text_add_callback");
+    doneSeriesGetContext(context, "keys_search_text_add_callback");
 }
 
 void
-redis_search_text_add(redisSlots *slots, pmSearchTextType type,
+keys_search_text_add(keySlots *slots, pmSearchTextType type,
 		const char *name, const char *indom,
 		const char *oneline, const char *helptext, void *arg)
 {
@@ -196,12 +196,12 @@ redis_search_text_add(redisSlots *slots, pmSearchTextType type,
     char		buffer[8];
     sds			cmd, key, docid;
 
-    seriesBatonCheckMagic(baton, MAGIC_LOAD, "redis_search_text_add");
+    seriesBatonCheckMagic(baton, MAGIC_LOAD, "keys_search_text_add");
 
     if (pmDebugOptions.search)
-	fprintf(stderr, "%s: %s %s\n", "redis_search_text_add", typestr, name);
+	fprintf(stderr, "%s: %s %s\n", "keys_search_text_add", typestr, name);
 
-    seriesBatonReference(context, "redis_search_text_add");
+    seriesBatonReference(context, "keys_search_text_add");
 
     /*
      * FT.ADD pcp:text <docid> 1.0
@@ -218,42 +218,42 @@ redis_search_text_add(redisSlots *slots, pmSearchTextType type,
 	length += 2;
     if (helptext && *helptext != '\0')
 	length += 2;
-    cmd = redis_command(length);
+    cmd = resp_command(length);
 
-    cmd = redis_param_str(cmd, FT_ADD, FT_ADD_LEN);
-    cmd = redis_param_str(cmd, FT_TEXT_KEY, FT_TEXT_KEY_LEN);
-    docid = redis_search_docid(FT_TEXT_KEY, typestr, name);
-    cmd = redis_param_sds(cmd, docid);
+    cmd = resp_param_str(cmd, FT_ADD, FT_ADD_LEN);
+    cmd = resp_param_str(cmd, FT_TEXT_KEY, FT_TEXT_KEY_LEN);
+    docid = keys_search_docid(FT_TEXT_KEY, typestr, name);
+    cmd = resp_param_sds(cmd, docid);
     sdsfree(docid);
-    cmd = redis_param_str(cmd, "1", 1);
+    cmd = resp_param_str(cmd, "1", 1);
 
-    cmd = redis_param_str(cmd, FT_REPLACE, FT_REPLACE_LEN);
-    cmd = redis_param_str(cmd, FT_PARTIAL, FT_PARTIAL_LEN);
+    cmd = resp_param_str(cmd, FT_REPLACE, FT_REPLACE_LEN);
+    cmd = resp_param_str(cmd, FT_PARTIAL, FT_PARTIAL_LEN);
 
     length = pmsprintf(buffer, sizeof(buffer), "%u", type);
-    cmd = redis_param_str(cmd, FT_PAYLOAD, FT_PAYLOAD_LEN);
-    cmd = redis_param_str(cmd, buffer, length);
+    cmd = resp_param_str(cmd, FT_PAYLOAD, FT_PAYLOAD_LEN);
+    cmd = resp_param_str(cmd, buffer, length);
 
-    cmd = redis_param_str(cmd, FT_FIELDS, FT_FIELDS_LEN);
-    cmd = redis_param_str(cmd, FT_NAME, FT_NAME_LEN);
-    cmd = redis_param_str(cmd, name, strlen(name));
-    cmd = redis_param_str(cmd, FT_TYPE, FT_TYPE_LEN);
-    cmd = redis_param_str(cmd, typestr, strlen(typestr));
+    cmd = resp_param_str(cmd, FT_FIELDS, FT_FIELDS_LEN);
+    cmd = resp_param_str(cmd, FT_NAME, FT_NAME_LEN);
+    cmd = resp_param_str(cmd, name, strlen(name));
+    cmd = resp_param_str(cmd, FT_TYPE, FT_TYPE_LEN);
+    cmd = resp_param_str(cmd, typestr, strlen(typestr));
     if (indom && *indom != '\0') {
-	cmd = redis_param_str(cmd, FT_INDOM, FT_INDOM_LEN);
-	cmd = redis_param_str(cmd, indom, strlen(indom));
+	cmd = resp_param_str(cmd, FT_INDOM, FT_INDOM_LEN);
+	cmd = resp_param_str(cmd, indom, strlen(indom));
     }
     if (oneline && *oneline != '\0') {
-	cmd = redis_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
-	cmd = redis_param_str(cmd, oneline, strlen(oneline));
+	cmd = resp_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
+	cmd = resp_param_str(cmd, oneline, strlen(oneline));
     }
     if (helptext && *helptext != '\0') {
-	cmd = redis_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
-	cmd = redis_param_str(cmd, helptext, strlen(helptext));
+	cmd = resp_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
+	cmd = resp_param_str(cmd, helptext, strlen(helptext));
     }
 
     sdsfree(key);
-    redisSlotsRequestFirstNode(slots, cmd, redis_search_text_add_callback, arg);
+    keySlotsRequestFirstNode(slots, cmd, keys_search_text_add_callback, arg);
     sdsfree(cmd);
 }
 
@@ -288,7 +288,7 @@ pmSearchDiscoverMetric(pmDiscoverEvent *event,
 	pmInDomStr_r(desc->indom, buffer, sizeof(buffer));
 
     for (i = 0; i < numnames; i++)
-	redis_search_text_add(baton->slots, PM_SEARCH_TYPE_METRIC,
+	keys_search_text_add(baton->slots, PM_SEARCH_TYPE_METRIC,
 			names[i], buffer, oneline, helptext, baton);
 
     if (oneline)
@@ -324,12 +324,12 @@ pmSearchDiscoverInDom(pmDiscoverEvent *event, pmInResult *in, void *arg)
     pmLookupText(id, PM_TEXT_INDOM | PM_TEXT_ONELINE, &oneline);
     pmLookupText(id, PM_TEXT_INDOM | PM_TEXT_HELP | PM_TEXT_DIRECT, &helptext);
 
-    redis_search_text_add(baton->slots, PM_SEARCH_TYPE_INDOM,
+    keys_search_text_add(baton->slots, PM_SEARCH_TYPE_INDOM,
 			buffer, buffer, oneline, helptext, baton);
     for (i = 0; i < in->numinst; i++) {
 	if (in->namelist[i] == NULL)
 	    continue;
-	redis_search_text_add(baton->slots, PM_SEARCH_TYPE_INST,
+	keys_search_text_add(baton->slots, PM_SEARCH_TYPE_INST,
 			in->namelist[i], buffer, NULL, NULL, baton);
     }
     if (oneline)
@@ -362,33 +362,33 @@ pmSearchDiscoverText(pmDiscoverEvent *event,
 	if ((count = pmNameAll(ident, &metrics)) <= 0)
 	    return;
 	for (i = 0; i < count; i++)
-	    redis_search_text_add(baton->slots, PM_SEARCH_TYPE_METRIC,
+	    keys_search_text_add(baton->slots, PM_SEARCH_TYPE_METRIC,
 			metrics[i], NULL, oneline, helptext, baton);
 	free(metrics);
     } else { /* PM_TEXT_INDOM */
 	pmInDomStr_r(ident, indom, sizeof(indom));
-	redis_search_text_add(baton->slots, PM_SEARCH_TYPE_INDOM,
+	keys_search_text_add(baton->slots, PM_SEARCH_TYPE_INDOM,
 			indom, indom, oneline, helptext, baton);
     }
 }
 
 static void
-redis_search_info_callback(
-	redisClusterAsyncContext *c, void *r, void *arg)
+keys_search_info_callback(
+	keyClusterAsyncContext *c, void *r, void *arg)
 {
-    redisSearchBaton	*baton = (redisSearchBaton *)arg;
-    redisReply		*reply = r;
-    redisReply		*child, *value;
+    keysSearchBaton	*baton = (keysSearchBaton *)arg;
+    respReply		*reply = r;
+    respReply		*child, *value;
     pmSearchMetrics	metrics = {0};
     int			i;
     sds			msg;
 
-    if (reply && reply->type == REDIS_REPLY_ARRAY && reply->elements >= 30) {
+    if (reply && reply->type == RESP_REPLY_ARRAY && reply->elements >= 30) {
 	for (i = 0; i < reply->elements-1; i++) {
 	    value = reply->element[i+1];
 	    child = reply->element[i];
-	    if (child->type != REDIS_REPLY_STRING &&
-		value->type != REDIS_REPLY_STRING)
+	    if (child->type != RESP_REPLY_STRING &&
+		value->type != RESP_REPLY_STRING)
 		continue;
 	    else if (strcmp("num_docs", child->str) == 0)
 		metrics.docs = strtoull(value->str, NULL, 0);
@@ -420,38 +420,38 @@ redis_search_info_callback(
 	baton->callbacks->on_metrics(&metrics, baton->userdata);
     } else {
 	infofmt(msg, "expected array from %s (reply=%s)",
-		FT_INFO, redis_reply_type(reply));
+		FT_INFO, resp_reply_type(reply));
 	batoninfo(baton, PMLOG_RESPONSE, msg);
 	baton->error = -EPROTO;
     }
 
     baton->callbacks->on_done(baton->error, baton->userdata);
-    doneRedisSearchBaton(baton);
+    doneKeysSearchBaton(baton);
 }
 
 void
-redis_search_info(redisSlots *slots, sds pcpkey, void *arg)
+keys_search_info(keySlots *slots, sds pcpkey, void *arg)
 {
-    redisSearchBaton	*baton = (redisSearchBaton *)arg;
+    keysSearchBaton	*baton = (keysSearchBaton *)arg;
     sds			cmd, key;
 
-    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "redis_search_info");
-    seriesBatonCheckCount(baton, "redis_search_info");
+    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "keys_search_info");
+    seriesBatonCheckCount(baton, "keys_search_info");
 
     if (pmDebugOptions.search)
-	fprintf(stderr, "%s: search key metrics\n", "redis_search_info");
+	fprintf(stderr, "%s: search key metrics\n", "keys_search_info");
 
-    seriesBatonReference(baton, "redis_search_info");
+    seriesBatonReference(baton, "keys_search_info");
 
     /*
      * FT.INFO pcp:<key>
      */
     key = sdscatfmt(sdsempty(), "pcp:%S", pcpkey);
-    cmd = redis_command(2);
-    cmd = redis_param_str(cmd, FT_INFO, FT_INFO_LEN);
-    cmd = redis_param_sds(cmd, key);
+    cmd = resp_command(2);
+    cmd = resp_param_str(cmd, FT_INFO, FT_INFO_LEN);
+    cmd = resp_param_sds(cmd, key);
     sdsfree(key);
-    redisSlotsRequestFirstNode(slots, cmd, redis_search_info_callback, arg);
+    keySlotsRequestFirstNode(slots, cmd, keys_search_info_callback, arg);
     sdsfree(cmd);
 }
 
@@ -459,23 +459,23 @@ int
 pmSearchInfo(pmSearchSettings *settings, sds key, void *arg)
 {
     seriesModuleData	*data = getSeriesModuleData(&settings->module);
-    redisSearchBaton	*baton;
+    keysSearchBaton	*baton;
 
     if (data == NULL)
 	return -ENOMEM;
-    if ((baton = calloc(1, sizeof(redisSearchBaton))) == NULL)
+    if ((baton = calloc(1, sizeof(keysSearchBaton))) == NULL)
 	return -ENOMEM;
-    initRedisSearchBaton(baton, data->slots, settings, arg);
-    redis_search_info(data->slots, key, baton);
+    initKeysSearchBaton(baton, data->slots, settings, arg);
+    keys_search_info(data->slots, key, baton);
     return 0;
 }
 
 static void
-extract_search_results(redisSearchBaton *baton,
-		unsigned int total, double timer, redisReply *reply)
+extract_search_results(keysSearchBaton *baton,
+		unsigned int total, double timer, respReply *reply)
 {
     pmSearchTextResult	result;
-    redisReply		*docid, *score, *payload, *array;
+    respReply		*docid, *score, *payload, *array;
     int			i, j;
 
     for (i = 1; i < reply->elements - 3; i += 4) {
@@ -483,10 +483,10 @@ extract_search_results(redisSearchBaton *baton,
 	score = reply->element[i+1];
 	payload = reply->element[i+2];
 	array = reply->element[i+3];
-	if (payload->type != REDIS_REPLY_STRING ||
-	    score->type != REDIS_REPLY_STRING ||
-	    docid->type != REDIS_REPLY_STRING ||
-	    array->type != REDIS_REPLY_ARRAY) {
+	if (payload->type != RESP_REPLY_STRING ||
+	    score->type != RESP_REPLY_STRING ||
+	    docid->type != RESP_REPLY_STRING ||
+	    array->type != RESP_REPLY_ARRAY) {
 	    baton->error = -EPROTO;
 	    break;
 	}
@@ -499,12 +499,12 @@ extract_search_results(redisSearchBaton *baton,
 	result.score = strtod(score->str, NULL);	
 
 	for (j = 0; j < array->elements; j += 2) {
-	    redisReply	*field = array->element[j];
-	    redisReply	*value = array->element[j+1];
+	    respReply	*field = array->element[j];
+	    respReply	*value = array->element[j+1];
 
-	    if (field->type != REDIS_REPLY_STRING ||
-	        (value->type != REDIS_REPLY_STRING &&
-		 value->type != REDIS_REPLY_NIL)) {
+	    if (field->type != RESP_REPLY_STRING ||
+	        (value->type != RESP_REPLY_STRING &&
+		 value->type != RESP_REPLY_NIL)) {
 		baton->error = -EPROTO;
 		break;
 	    }
@@ -532,24 +532,24 @@ extract_search_results(redisSearchBaton *baton,
 }
 
 static void
-redis_search_text_query_callback(
-	redisClusterAsyncContext *c, void *r, void *arg)
+keys_search_text_query_callback(
+	keyClusterAsyncContext *c, void *r, void *arg)
 {
-    redisSearchBaton	*baton = (redisSearchBaton *)arg;
-    redisReply		*reply = r;
-    redisReply		*value;
+    keysSearchBaton	*baton = (keysSearchBaton *)arg;
+    respReply		*reply = r;
+    respReply		*value;
     struct timespec	finished;
     unsigned int	total;
     double		timer;
     sds			msg;
 
-    if (LIKELY(reply && reply->type == REDIS_REPLY_ARRAY)) {
+    if (LIKELY(reply && reply->type == RESP_REPLY_ARRAY)) {
 	value = reply->element[0];
 	if (reply->elements == 1)	/* no search results - done! */
 	    /* do nothing */;
 	else if (reply->elements < 2)	/* expect total then results */
 	    baton->error = -EPROTO;
-	else if (value->type != REDIS_REPLY_INTEGER)
+	else if (value->type != RESP_REPLY_INTEGER)
 	    baton->error = -EPROTO;
 	else {
 	    pmtimespecNow(&finished);
@@ -559,32 +559,32 @@ redis_search_text_query_callback(
 	}
     } else {
 	infofmt(msg, "expected array from %s (reply=%s)",
-		FT_SEARCH, redis_reply_type(reply));
+		FT_SEARCH, resp_reply_type(reply));
 	batoninfo(baton, PMLOG_RESPONSE, msg);
 	baton->error = -EPROTO;
     }
 
     baton->callbacks->on_done(baton->error, baton->userdata);
-    doneRedisSearchBaton(baton);
+    doneKeysSearchBaton(baton);
 }
 
 static void
-redis_search_text_query(redisSlots *slots, pmSearchTextRequest *request, void *arg)
+keys_search_text_query(keySlots *slots, pmSearchTextRequest *request, void *arg)
 {
-    redisSearchBaton	*baton = (redisSearchBaton *)arg;
+    keysSearchBaton	*baton = (keysSearchBaton *)arg;
     const char		*typestr;
     size_t		length;
     char		buffer[64];
     sds			cmd, key, query, base_query;
     unsigned int	types = 0, infields = 0, returns = 0, highlights = 0;
 
-    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "redis_search_text_query");
-    seriesBatonCheckCount(baton, "redis_search_text_query");
+    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "keys_search_text_query");
+    seriesBatonCheckCount(baton, "keys_search_text_query");
 
     if (pmDebugOptions.search)
-	fprintf(stderr, "%s: %s\n", "redis_search_text_query", request->query);
+	fprintf(stderr, "%s: %s\n", "keys_search_text_query", request->query);
 
-    seriesBatonReference(baton, "redis_search_text_query");
+    seriesBatonReference(baton, "keys_search_text_query");
 
     types += request->type_metric;
     types += request->type_indom;
@@ -636,9 +636,9 @@ redis_search_text_query(redisSlots *slots, pmSearchTextRequest *request, void *a
 	length += 3 + highlights;
     length += 2 + 3;
 
-    cmd = redis_command(length);
-    cmd = redis_param_str(cmd, FT_SEARCH, FT_SEARCH_LEN);
-    cmd = redis_param_sds(cmd, key);
+    cmd = resp_command(length);
+    cmd = resp_param_str(cmd, FT_SEARCH, FT_SEARCH_LEN);
+    cmd = resp_param_sds(cmd, key);
 
     query = sdscatlen(sdsempty(), "\'", 1);
     if (types) {
@@ -661,72 +661,72 @@ redis_search_text_query(redisSlots *slots, pmSearchTextRequest *request, void *a
 	}
 	query = sdscatlen(query, "} ", 2);
     }
-    base_query = redis_search_text_prep(request->query, 0, NULL, NULL);
+    base_query = keys_search_text_prep(request->query, 0, NULL, NULL);
     query = sdscatfmt(query, "(%S)=>{$inorder:true}\'", base_query);
     sdsfree(base_query);
-    cmd = redis_param_sds(cmd, query);
+    cmd = resp_param_sds(cmd, query);
     sdsfree(query);
 
-    cmd = redis_param_str(cmd, FT_WITHSCORES, FT_WITHSCORES_LEN);
-    cmd = redis_param_str(cmd, FT_WITHPAYLOADS, FT_WITHPAYLOADS_LEN);
+    cmd = resp_param_str(cmd, FT_WITHSCORES, FT_WITHSCORES_LEN);
+    cmd = resp_param_str(cmd, FT_WITHPAYLOADS, FT_WITHPAYLOADS_LEN);
 
     if (infields) {
-	cmd = redis_param_str(cmd, FT_INFIELDS, FT_INFIELDS_LEN);
+	cmd = resp_param_str(cmd, FT_INFIELDS, FT_INFIELDS_LEN);
 	length = pmsprintf(buffer, sizeof(buffer), "%u", infields);
-	cmd = redis_param_str(cmd, buffer, length);
+	cmd = resp_param_str(cmd, buffer, length);
 	if (request->infields_name)
-	    cmd = redis_param_str(cmd, FT_NAME, FT_NAME_LEN);
+	    cmd = resp_param_str(cmd, FT_NAME, FT_NAME_LEN);
 	if (request->infields_oneline)
-	    cmd = redis_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
+	    cmd = resp_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
 	if (request->infields_helptext)
-	    cmd = redis_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
+	    cmd = resp_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
     }
 
     if (returns) {
-	cmd = redis_param_str(cmd, FT_RETURN, FT_RETURN_LEN);
+	cmd = resp_param_str(cmd, FT_RETURN, FT_RETURN_LEN);
 	length = pmsprintf(buffer, sizeof(buffer), "%u", returns);
-	cmd = redis_param_str(cmd, buffer, length);
+	cmd = resp_param_str(cmd, buffer, length);
 	if (request->return_name)
-	    cmd = redis_param_str(cmd, FT_NAME, FT_NAME_LEN);
+	    cmd = resp_param_str(cmd, FT_NAME, FT_NAME_LEN);
 	if (request->return_indom)
-	    cmd = redis_param_str(cmd, FT_INDOM, FT_INDOM_LEN);
+	    cmd = resp_param_str(cmd, FT_INDOM, FT_INDOM_LEN);
 	if (request->return_oneline)
-	    cmd = redis_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
+	    cmd = resp_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
 	if (request->return_helptext)
-	    cmd = redis_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
+	    cmd = resp_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
 	if (request->return_type)
-	    cmd = redis_param_str(cmd, FT_TYPE, FT_TYPE_LEN);
+	    cmd = resp_param_str(cmd, FT_TYPE, FT_TYPE_LEN);
     }
 
     if (highlights) {
-	cmd = redis_param_str(cmd, FT_HIGHLIGHT, FT_HIGHLIGHT_LEN);
-	cmd = redis_param_str(cmd, FT_FIELDS, FT_FIELDS_LEN);
+	cmd = resp_param_str(cmd, FT_HIGHLIGHT, FT_HIGHLIGHT_LEN);
+	cmd = resp_param_str(cmd, FT_FIELDS, FT_FIELDS_LEN);
 	length = pmsprintf(buffer, sizeof(buffer), "%u", highlights);
-	cmd = redis_param_str(cmd, buffer, length);
+	cmd = resp_param_str(cmd, buffer, length);
 	if (request->highlight_name)
-	    cmd = redis_param_str(cmd, FT_NAME, FT_NAME_LEN);
+	    cmd = resp_param_str(cmd, FT_NAME, FT_NAME_LEN);
 	if (request->highlight_oneline)
-	    cmd = redis_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
+	    cmd = resp_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
 	if (request->highlight_helptext)
-	    cmd = redis_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
+	    cmd = resp_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
     }
 
-    cmd = redis_param_str(cmd, FT_SCORER, FT_SCORER_LEN);
-    cmd = redis_param_str(cmd, FT_SCORER_BM25, FT_SCORER_BM25_LEN);
+    cmd = resp_param_str(cmd, FT_SCORER, FT_SCORER_LEN);
+    cmd = resp_param_str(cmd, FT_SCORER_BM25, FT_SCORER_BM25_LEN);
 
-    cmd = redis_param_str(cmd, FT_LIMIT, FT_LIMIT_LEN);
+    cmd = resp_param_str(cmd, FT_LIMIT, FT_LIMIT_LEN);
     length = pmsprintf(buffer, sizeof(buffer), "%u", request->offset);
-    cmd = redis_param_str(cmd, buffer, length);
+    cmd = resp_param_str(cmd, buffer, length);
     if (request->count == 0) {
-	cmd = redis_param_sds(cmd, resultcount_str);
+	cmd = resp_param_sds(cmd, resultcount_str);
 	request->count = resultcount;
     } else {
 	length = pmsprintf(buffer, sizeof(buffer), "%u", request->count);
-	cmd = redis_param_str(cmd, buffer, length);
+	cmd = resp_param_str(cmd, buffer, length);
     }
 
     sdsfree(key);
-    redisSlotsRequestFirstNode(slots, cmd, redis_search_text_query_callback, arg);
+    keySlotsRequestFirstNode(slots, cmd, keys_search_text_query_callback, arg);
     sdsfree(cmd);
 }
 
@@ -734,38 +734,38 @@ int
 pmSearchTextQuery(pmSearchSettings *settings, pmSearchTextRequest *request, void *arg)
 {
     seriesModuleData	*data = getSeriesModuleData(&settings->module);
-    redisSearchBaton	*baton;
+    keysSearchBaton	*baton;
 
     if (data == NULL)
 	return -ENOMEM;
-    if ((baton = calloc(1, sizeof(redisSearchBaton))) == NULL)
+    if ((baton = calloc(1, sizeof(keysSearchBaton))) == NULL)
 	return -ENOMEM;
-    initRedisSearchBaton(baton, data->slots, settings, arg);
-    redis_search_text_query(data->slots, request, baton);
+    initKeysSearchBaton(baton, data->slots, settings, arg);
+    keys_search_text_query(data->slots, request, baton);
     return 0;
 }
 
 static void
-redis_search_text_suggest(redisSlots *slots, pmSearchTextRequest *request, void *arg)
+keys_search_text_suggest(keySlots *slots, pmSearchTextRequest *request, void *arg)
 {
-    redisSearchBaton	*baton = (redisSearchBaton *)arg;
+    keysSearchBaton	*baton = (keysSearchBaton *)arg;
     size_t		length, prefix_length, fuzzy_length;
     const char		*prefix;
     char		buffer[64];
     sds			cmd, key, query,
     			prefix_query, fuzzy_query;
 
-    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "redis_search_text_suggest");
-    seriesBatonCheckCount(baton, "redis_search_text_suggest");
+    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "keys_search_text_suggest");
+    seriesBatonCheckCount(baton, "keys_search_text_suggest");
 
     if (pmDebugOptions.search)
-	fprintf(stderr, "%s: %s\n", "redis_search_text_suggest", request->query);
+	fprintf(stderr, "%s: %s\n", "keys_search_text_suggest", request->query);
 
-    seriesBatonReference(baton, "redis_search_text_suggest");
+    seriesBatonReference(baton, "keys_search_text_suggest");
 
     /* by default we cannot use prefix search with words of length less than 2 */
-    prefix_query = redis_search_text_prep(request->query, 2, NULL, "*");
-    fuzzy_query = redis_search_text_prep(request->query, 2, "%", "%");
+    prefix_query = keys_search_text_prep(request->query, 2, NULL, "*");
+    fuzzy_query = keys_search_text_prep(request->query, 2, "%", "%");
     prefix_length = sdslen(prefix_query);
     fuzzy_length = sdslen(fuzzy_query);
 
@@ -808,31 +808,31 @@ redis_search_text_suggest(redisSlots *slots, pmSearchTextRequest *request, void
     key = sdsnewlen(FT_TEXT_KEY, FT_TEXT_KEY_LEN);
 
     length = 13; // Resp array size
-    cmd = redis_command(length);
-    cmd = redis_param_str(cmd, FT_SEARCH, FT_SEARCH_LEN);
-    cmd = redis_param_sds(cmd, key);
-    cmd = redis_param_sds(cmd, query);
+    cmd = resp_command(length);
+    cmd = resp_param_str(cmd, FT_SEARCH, FT_SEARCH_LEN);
+    cmd = resp_param_sds(cmd, key);
+    cmd = resp_param_sds(cmd, query);
     sdsfree(query);
 
-    cmd = redis_param_str(cmd, FT_WITHSCORES, FT_WITHSCORES_LEN);
-    cmd = redis_param_str(cmd, FT_WITHPAYLOADS, FT_WITHPAYLOADS_LEN);
-    cmd = redis_param_str(cmd, FT_RETURN, FT_RETURN_LEN);
-    cmd = redis_param_str(cmd, "1", 1);
-    cmd = redis_param_str(cmd, FT_NAME, FT_NAME_LEN);
-    cmd = redis_param_str(cmd, FT_SCORER, FT_SCORER_LEN);
-    cmd = redis_param_str(cmd, FT_SCORER_BM25, FT_SCORER_BM25_LEN);
-    cmd = redis_param_str(cmd, FT_LIMIT, FT_LIMIT_LEN);
-    cmd = redis_param_str(cmd, "0", 1);
+    cmd = resp_param_str(cmd, FT_WITHSCORES, FT_WITHSCORES_LEN);
+    cmd = resp_param_str(cmd, FT_WITHPAYLOADS, FT_WITHPAYLOADS_LEN);
+    cmd = resp_param_str(cmd, FT_RETURN, FT_RETURN_LEN);
+    cmd = resp_param_str(cmd, "1", 1);
+    cmd = resp_param_str(cmd, FT_NAME, FT_NAME_LEN);
+    cmd = resp_param_str(cmd, FT_SCORER, FT_SCORER_LEN);
+    cmd = resp_param_str(cmd, FT_SCORER_BM25, FT_SCORER_BM25_LEN);
+    cmd = resp_param_str(cmd, FT_LIMIT, FT_LIMIT_LEN);
+    cmd = resp_param_str(cmd, "0", 1);
     if (request->count == 0) {
-	cmd = redis_param_sds(cmd, resultcount_str);
+	cmd = resp_param_sds(cmd, resultcount_str);
 	request->count = resultcount;
     } else {
 	length = pmsprintf(buffer, sizeof(buffer), "%u", request->count);
-	cmd = redis_param_str(cmd, buffer, length);
+	cmd = resp_param_str(cmd, buffer, length);
     }
 
     sdsfree(key);
-    redisSlotsRequestFirstNode(slots, cmd, redis_search_text_query_callback, arg);
+    keySlotsRequestFirstNode(slots, cmd, keys_search_text_query_callback, arg);
     sdsfree(cmd);
 }
 
@@ -840,32 +840,32 @@ int
 pmSearchTextSuggest(pmSearchSettings *settings, pmSearchTextRequest *request, void *arg)
 {
     seriesModuleData	*data = getSeriesModuleData(&settings->module);
-    redisSearchBaton	*baton;
+    keysSearchBaton	*baton;
 
     if (data == NULL)
 	return -ENOMEM;
-    if ((baton = calloc(1, sizeof(redisSearchBaton))) == NULL)
+    if ((baton = calloc(1, sizeof(keysSearchBaton))) == NULL)
 	return -ENOMEM;
-    initRedisSearchBaton(baton, data->slots, settings, arg);
-    redis_search_text_suggest(data->slots, request, baton);
+    initKeysSearchBaton(baton, data->slots, settings, arg);
+    keys_search_text_suggest(data->slots, request, baton);
     return 0;
 }
 
 static void
-redis_search_text_indom(redisSlots *slots, pmSearchTextRequest *request, void *arg)
+keys_search_text_indom(keySlots *slots, pmSearchTextRequest *request, void *arg)
 {
-    redisSearchBaton	*baton = (redisSearchBaton *)arg;
+    keysSearchBaton	*baton = (keysSearchBaton *)arg;
     size_t		length;
     char		buffer[64];
     sds			cmd, key, query;
 
-    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "redis_search_text_indom");
-    seriesBatonCheckCount(baton, "redis_search_text_indom");
+    seriesBatonCheckMagic(baton, MAGIC_SEARCH, "keys_search_text_indom");
+    seriesBatonCheckCount(baton, "keys_search_text_indom");
 
     if (pmDebugOptions.search)
-	fprintf(stderr, "%s: %s\n", "redis_search_text_indom", request->query);
+	fprintf(stderr, "%s: %s\n", "keys_search_text_indom", request->query);
 
-    seriesBatonReference(baton, "redis_search_text_indom");
+    seriesBatonReference(baton, "keys_search_text_indom");
 
     query = sdscatfmt(
 	sdsnewlen("", 0),
@@ -882,33 +882,33 @@ redis_search_text_indom(redisSlots *slots, pmSearchTextRequest *request, void *a
     key = sdsnewlen(FT_TEXT_KEY, FT_TEXT_KEY_LEN);
 
     length = 12; // Resp array size
-    cmd = redis_command(length);
-    cmd = redis_param_str(cmd, FT_SEARCH, FT_SEARCH_LEN);
-    cmd = redis_param_sds(cmd, key);
-    cmd = redis_param_sds(cmd, query);
+    cmd = resp_command(length);
+    cmd = resp_param_str(cmd, FT_SEARCH, FT_SEARCH_LEN);
+    cmd = resp_param_sds(cmd, key);
+    cmd = resp_param_sds(cmd, query);
     sdsfree(query);
 
-    cmd = redis_param_str(cmd, FT_WITHSCORES, FT_WITHSCORES_LEN);
-    cmd = redis_param_str(cmd, FT_WITHPAYLOADS, FT_WITHPAYLOADS_LEN);
+    cmd = resp_param_str(cmd, FT_WITHSCORES, FT_WITHSCORES_LEN);
+    cmd = resp_param_str(cmd, FT_WITHPAYLOADS, FT_WITHPAYLOADS_LEN);
 
-    cmd = redis_param_str(cmd, FT_SORTBY, FT_SORTBY_LEN);
-    cmd = redis_param_str(cmd, "2", 1);
-    cmd = redis_param_str(cmd, FT_TYPE, FT_TYPE_LEN);
-    cmd = redis_param_str(cmd, FT_ASC, FT_ASC_LEN);
+    cmd = resp_param_str(cmd, FT_SORTBY, FT_SORTBY_LEN);
+    cmd = resp_param_str(cmd, "2", 1);
+    cmd = resp_param_str(cmd, FT_TYPE, FT_TYPE_LEN);
+    cmd = resp_param_str(cmd, FT_ASC, FT_ASC_LEN);
 
-    cmd = redis_param_str(cmd, FT_LIMIT, FT_LIMIT_LEN);
+    cmd = resp_param_str(cmd, FT_LIMIT, FT_LIMIT_LEN);
     length = pmsprintf(buffer, sizeof(buffer), "%u", request->offset);
-    cmd = redis_param_str(cmd, buffer, length);
+    cmd = resp_param_str(cmd, buffer, length);
     if (request->count == 0) {
-	cmd = redis_param_sds(cmd, resultcount_str);
+	cmd = resp_param_sds(cmd, resultcount_str);
 	request->count = resultcount;
     } else {
 	length = pmsprintf(buffer, sizeof(buffer), "%u", request->count);
-	cmd = redis_param_str(cmd, buffer, length);
+	cmd = resp_param_str(cmd, buffer, length);
     }
 
     sdsfree(key);
-    redisSlotsRequestFirstNode(slots, cmd, redis_search_text_query_callback, arg);
+    keySlotsRequestFirstNode(slots, cmd, keys_search_text_query_callback, arg);
     sdsfree(cmd);
 }
 
@@ -916,54 +916,54 @@ int
 pmSearchTextInDom(pmSearchSettings *settings, pmSearchTextRequest *request, void *arg)
 {
     seriesModuleData	*data = getSeriesModuleData(&settings->module);
-    redisSearchBaton	*baton;
+    keysSearchBaton	*baton;
 
     if (data == NULL)
 	return -ENOMEM;
-    if ((baton = calloc(1, sizeof(redisSearchBaton))) == NULL)
+    if ((baton = calloc(1, sizeof(keysSearchBaton))) == NULL)
 	return -ENOMEM;
-    initRedisSearchBaton(baton, data->slots, settings, arg);
-    redis_search_text_indom(data->slots, request, baton);
+    initKeysSearchBaton(baton, data->slots, settings, arg);
+    keys_search_text_indom(data->slots, request, baton);
     return 0;
 }
 
 static void
-redis_search_schema_callback(
-	redisClusterAsyncContext *c, void *r, void *arg)
+keys_search_schema_callback(
+	keyClusterAsyncContext *c, void *r, void *arg)
 {
-    redisSlotsBaton	*baton = (redisSlotsBaton *)arg;
-    redisReply		*reply = r;
+    keySlotsBaton	*baton = (keySlotsBaton *)arg;
+    respReply		*reply = r;
 
-    seriesBatonCheckMagic(baton, MAGIC_SLOTS, "redis_search_schema_callback");
+    seriesBatonCheckMagic(baton, MAGIC_SLOTS, "keys_search_schema_callback");
 
-    if (testReplyError(reply, REDIS_EDROPINDEX)) {
+    if (testReplyError(reply, RESP_EDROPINDEX)) {
 	// index already exists
 	baton->slots->search = 1;
     }
-    else if (reply && reply->type == REDIS_REPLY_STATUS &&
+    else if (reply && reply->type == RESP_REPLY_STATUS &&
 	(strcmp("OK", reply->str) == 0 || strcmp("QUEUED", reply->str) == 0)) {
 	// index created
 	baton->slots->search = 1;
     } else {
-	// probably no RediSearch module installed, ignore silently
+	// probably no search module installed, ignore silently
 	baton->slots->search = 0;
     }
 
-    redis_slots_end_phase(baton);
+    keys_slots_end_phase(baton);
 }
 
 void
-redis_load_search_schema(void *arg)
+keys_load_search_schema(void *arg)
 {
-    redisSlotsBaton	*baton = (redisSlotsBaton *)arg;
+    keySlotsBaton	*baton = (keySlotsBaton *)arg;
     sds			cmd, key;
 
-    seriesBatonCheckMagic(baton, MAGIC_SLOTS, "redis_load_search_schema");
+    seriesBatonCheckMagic(baton, MAGIC_SLOTS, "keys_load_search_schema");
 
     if (pmDebugOptions.search && pmDebugOptions.desperate)
-	fprintf(stderr, "%s: loading schema\n", "redis_search_schema");
+	fprintf(stderr, "%s: loading schema\n", "keys_search_schema");
         
-    seriesBatonReference(baton, "redis_load_search_schema");
+    seriesBatonReference(baton, "keys_load_search_schema");
 
     /*
      * FT.CREATE pcp:text SCHEMA
@@ -974,37 +974,37 @@ redis_load_search_schema(void *arg)
      *		helptext TEXT WEIGHT 2
      */
     key = sdsnewlen(FT_TEXT_KEY, FT_TEXT_KEY_LEN);
-    cmd = redis_command(3 + 3 + 5 + 2 + 4 + 4);
+    cmd = resp_command(3 + 3 + 5 + 2 + 4 + 4);
 
-    cmd = redis_param_str(cmd, FT_CREATE, FT_CREATE_LEN);
-    cmd = redis_param_str(cmd, FT_TEXT_KEY, FT_TEXT_KEY_LEN);
-    cmd = redis_param_str(cmd, FT_SCHEMA, FT_SCHEMA_LEN);
+    cmd = resp_param_str(cmd, FT_CREATE, FT_CREATE_LEN);
+    cmd = resp_param_str(cmd, FT_TEXT_KEY, FT_TEXT_KEY_LEN);
+    cmd = resp_param_str(cmd, FT_SCHEMA, FT_SCHEMA_LEN);
 
-    cmd = redis_param_str(cmd, FT_TYPE, FT_TYPE_LEN);
-    cmd = redis_param_str(cmd, FT_TAG, FT_TAG_LEN);
-    cmd = redis_param_str(cmd, FT_SORTABLE, FT_SORTABLE_LEN);
+    cmd = resp_param_str(cmd, FT_TYPE, FT_TYPE_LEN);
+    cmd = resp_param_str(cmd, FT_TAG, FT_TAG_LEN);
+    cmd = resp_param_str(cmd, FT_SORTABLE, FT_SORTABLE_LEN);
 
-    cmd = redis_param_str(cmd, FT_NAME, FT_NAME_LEN);
-    cmd = redis_param_str(cmd, FT_TEXT, FT_TEXT_LEN);
-    cmd = redis_param_str(cmd, FT_WEIGHT, FT_WEIGHT_LEN);
-    cmd = redis_param_str(cmd, "9", sizeof("9")-1);
-    cmd = redis_param_str(cmd, FT_SORTABLE, FT_SORTABLE_LEN);
+    cmd = resp_param_str(cmd, FT_NAME, FT_NAME_LEN);
+    cmd = resp_param_str(cmd, FT_TEXT, FT_TEXT_LEN);
+    cmd = resp_param_str(cmd, FT_WEIGHT, FT_WEIGHT_LEN);
+    cmd = resp_param_str(cmd, "9", sizeof("9")-1);
+    cmd = resp_param_str(cmd, FT_SORTABLE, FT_SORTABLE_LEN);
 
-    cmd = redis_param_str(cmd, FT_INDOM, FT_INDOM_LEN);
-    cmd = redis_param_str(cmd, FT_TAG, FT_TAG_LEN);
+    cmd = resp_param_str(cmd, FT_INDOM, FT_INDOM_LEN);
+    cmd = resp_param_str(cmd, FT_TAG, FT_TAG_LEN);
 
-    cmd = redis_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
-    cmd = redis_param_str(cmd, FT_TEXT, FT_TEXT_LEN);
-    cmd = redis_param_str(cmd, FT_WEIGHT, FT_WEIGHT_LEN);
-    cmd = redis_param_str(cmd, "4", sizeof("4")-1);
+    cmd = resp_param_str(cmd, FT_ONELINE, FT_ONELINE_LEN);
+    cmd = resp_param_str(cmd, FT_TEXT, FT_TEXT_LEN);
+    cmd = resp_param_str(cmd, FT_WEIGHT, FT_WEIGHT_LEN);
+    cmd = resp_param_str(cmd, "4", sizeof("4")-1);
 
-    cmd = redis_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
-    cmd = redis_param_str(cmd, FT_TEXT, FT_TEXT_LEN);
-    cmd = redis_param_str(cmd, FT_WEIGHT, FT_WEIGHT_LEN);
-    cmd = redis_param_str(cmd, "2", sizeof("2")-1);
+    cmd = resp_param_str(cmd, FT_HELPTEXT, FT_HELPTEXT_LEN);
+    cmd = resp_param_str(cmd, FT_TEXT, FT_TEXT_LEN);
+    cmd = resp_param_str(cmd, FT_WEIGHT, FT_WEIGHT_LEN);
+    cmd = resp_param_str(cmd, "2", sizeof("2")-1);
 
     sdsfree(key);
-    redisSlotsRequestFirstNode(baton->slots, cmd, redis_search_schema_callback, arg);
+    keySlotsRequestFirstNode(baton->slots, cmd, keys_search_schema_callback, arg);
     sdsfree(cmd);
 }
 
@@ -1033,7 +1033,7 @@ pmSearchSetMetricRegistry(pmSearchModule *module, mmv_registry_t *registry)
 }
 
 void
-redisSearchInit(struct dict *config)
+keysSearchInit(struct dict *config)
 {
     sds		option;
 
@@ -1047,7 +1047,7 @@ redisSearchInit(struct dict *config)
 }
 
 void
-redisSearchClose(void)
+keysSearchClose(void)
 {
     if (DEFAULT_RESULTCOUNT) {
 	sdsfree(DEFAULT_RESULTCOUNT);
@@ -1060,24 +1060,25 @@ pmSearchSetup(pmSearchModule *module, void *arg)
 {
     seriesModuleData	*data = getSeriesModuleData(module);
     sds			option;
-    redisSlotsFlags	flags;
+    keySlotsFlags	flags;
 
     if (data == NULL)
 	return -ENOMEM;
 
     /* create string map caches */
-    redisGlobalsInit(data->config);
+    keysGlobalsInit(data->config);
 
-    /* fast path for when Redis has been setup already */
+    /* fast path for when key server has been setup already */
     if (data->slots) {
 	module->on_setup(arg);
 	data->shareslots = 1;
     } else {
-	option = pmIniFileLookup(data->config, "redis", "enabled");
+	if (!(option = pmIniFileLookup(data->config, "resp", "enabled")))
+	    option = pmIniFileLookup(data->config, "redis", "enabled"); // compat
 	if (option && strcmp(option, "false") == 0)
 	    return -ENOTSUP;
 
-	/* establish an initial connection to Redis instance(s) */
+	/* establish an initial connection to key server instance(s) */
 	flags = SLOTS_VERSION;
 
 	option = pmIniFileLookup(data->config, "pmsearch", "enabled");
@@ -1086,8 +1087,8 @@ pmSearchSetup(pmSearchModule *module, void *arg)
 	else
 	    return -ENOTSUP;
 
-	/* establish an initial connection to Redis instance(s) */
-	data->slots = redisSlotsConnect(
+	/* establish an initial connection to key server instance(s) */
+	data->slots = keySlotsConnect(
 			data->config, flags, module->on_info,
 			module->on_setup, arg, data->events, arg);
 	data->shareslots = 0;
@@ -1098,7 +1099,7 @@ pmSearchSetup(pmSearchModule *module, void *arg)
 int
 pmSearchEnabled(void *arg)
 {
-    redisSlots	*slots = (redisSlots *)arg;
+    keySlots	*slots = (keySlots *)arg;
 
     if (slots)
 	return slots->search > 0 ? 1 : 0;
@@ -1112,11 +1113,11 @@ pmSearchClose(pmSearchModule *module)
 
     if (search) {
 	if (search->slots && !search->shareslots)
-	    redisSlotsFree(search->slots);
+	    keySlotsFree(search->slots);
 	memset(search, 0, sizeof(*search));
 	free(search);
 	module->privdata = NULL;
     }
 
-    redisGlobalsClose();
+    keysGlobalsClose();
 }
