@@ -1,12 +1,12 @@
 /*
- * Copyright (c) 2014,2021 Red Hat.
+ * Copyright (c) 2014,2021,2023 Red Hat.
  * Copyright (c) 2007-2009, Aconex.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
@@ -21,7 +21,27 @@
 SaveViewDialog::SaveViewDialog(QWidget* parent) : QDialog(parent)
 {
     setupUi(this);
-    my.dirModel = new QDirModel;
+
+    connect(savePushButton, SIGNAL(clicked()),
+		this, SLOT(savePushButton_clicked()));
+    connect(fileNameLineEdit, SIGNAL(returnPressed()),
+		savePushButton, SLOT(click()));
+    connect(cancelButton, SIGNAL(clicked()),
+		this, SLOT(reject()));
+    connect(preserveHostCheckBox, SIGNAL(toggled(bool)),
+		this, SLOT(preserveHostCheckBox_toggled(bool)));
+    connect(parentToolButton, SIGNAL(clicked()),
+		this, SLOT(parentToolButton_clicked()));
+    connect(userToolButton, SIGNAL(clicked(bool)),
+		this, SLOT(userToolButton_clicked(bool)));
+    connect(pathComboBox, SIGNAL(currentIndexChanged(int)),
+		this, SLOT(pathComboBox_currentIndexChanged(int)));
+    connect(dirListView, SIGNAL(activated(QModelIndex)),
+		this, SLOT(dirListView_activated(QModelIndex)));
+    connect(preserveSizeCheckBox, SIGNAL(toggled(bool)),
+		this, SLOT(preserveSizeCheckBox_toggled(bool)));
+
+    my.dirModel = new QFileSystemModel;
     my.dirModel->setIconProvider(fileIconProvider);
     dirListView->setModel(my.dirModel);
 
@@ -88,7 +108,6 @@ void SaveViewDialog::setPath(const QModelIndex &index)
     console->post("SaveViewDialog::setPath QModelIndex path=%s",
 			(const char *)my.dirModel->filePath(index).toLatin1());
     my.dirIndex = index;
-    my.dirModel->refresh(index);
     dirListView->setRootIndex(index);
     setPathUi(my.dirModel->filePath(index));
 }
@@ -97,16 +116,16 @@ void SaveViewDialog::setPath(const QString &path)
 {
     console->post("SaveViewDialog::setPath QString path=%s",
 			(const char *)path.toLatin1());
+    my.dirModel->setRootPath(path);
     my.dirIndex = my.dirModel->index(path);
-    my.dirModel->refresh(my.dirIndex);
     dirListView->setRootIndex(my.dirIndex);
     setPathUi(path);
 }
 
-void SaveViewDialog::pathComboBox_currentIndexChanged(QString path)
+void SaveViewDialog::pathComboBox_currentIndexChanged(int index)
 {
     console->post("SaveViewDialog::pathComboBox_currentIndexChanged");
-    setPath(path);
+    setPath(pathComboBox->itemText(index));
 }
 
 void SaveViewDialog::parentToolButton_clicked()
@@ -152,9 +171,7 @@ void SaveViewDialog::dirListView_activated(const QModelIndex &index)
 	QString msg = fi.filePath();
 	msg.prepend(tr("View file "));
 	msg.append(tr(" exists.  Overwrite?\n"));
-	if (QMessageBox::question(this, pmGetProgname(), msg,
-	    QMessageBox::Cancel|QMessageBox::Default|QMessageBox::Escape,
-	    QMessageBox::Ok, QMessageBox::NoButton) == QMessageBox::Ok)
+	if (QMessageBox::question(this, pmGetProgname(), msg) == QMessageBox::Yes)
 	    if (saveViewFile(fi.absoluteFilePath()) == true)
 		done(0);
     }
@@ -205,9 +222,7 @@ void SaveViewDialog::savePushButton_clicked()
 	    msg = filename;
 	    msg.prepend(tr("View file "));
 	    msg.append(tr(" exists.  Overwrite?\n"));
-	    if (QMessageBox::question(this, pmGetProgname(), msg,
-		QMessageBox::Cancel|QMessageBox::Default|QMessageBox::Escape,
-		QMessageBox::Ok, QMessageBox::NoButton) == QMessageBox::Ok)
+	    if (QMessageBox::question(this, pmGetProgname(), msg) == QMessageBox::Yes)
 		if (saveViewFile(fi.absoluteFilePath()) == true)
 		    done(0);
 	    msg = "";
@@ -217,8 +232,6 @@ void SaveViewDialog::savePushButton_clicked()
     }
 
     if (msg.isEmpty() == false) {
-	QMessageBox::warning(this, pmGetProgname(), msg,
-	    QMessageBox::Ok|QMessageBox::Default|QMessageBox::Escape,
-	    QMessageBox::NoButton, QMessageBox::NoButton);
+	QMessageBox::warning(this, pmGetProgname(), msg);
     }
 }
