@@ -66,8 +66,10 @@ get_distro_info(void)
 	 */
 	distro_name = (char *)malloc(len + (int)sbuf.st_size + 1);
 	if (distro_name != NULL) {
-	    if (len)
-		strncpy(distro_name, prefix, len);
+	    if (len) {
+		strncpy(distro_name, prefix, len + sbuf.st_size);
+		distro_name[len + sbuf.st_size] = '\0';	/* buffer overrun guard */
+	    }
 	    sts = read(fd, distro_name + len, (int)sbuf.st_size);
 	    if (sts <= 0) {
 		free(distro_name);
@@ -75,13 +77,13 @@ get_distro_info(void)
 	    } else {
 		char *nl;
 
+		distro_name[sts + len] = '\0';
 		if (r == LSB_RELEASE) {	/* may be Ubuntu */
 		    if (!strncmp(distro_name, "DISTRIB_ID = ", 13))
 			distro_name += 13;	/* ick */
 		    if (!strncmp(distro_name, "DISTRIB_ID=", 11))
 			distro_name += 11;	/* more ick */
 		}
-		distro_name[sts + len] = '\0';
 		if ((nl = strchr(distro_name, '\n')) != NULL)
 		    *nl = '\0';
 	    }
