@@ -244,6 +244,9 @@ enum {
     _PM_NETSTAT_MPTCPEXT_MPCURRESTAB,
     _PM_NETSTAT_MPTCPEXT_MPJOINSYNBACKUPRX,
     _PM_NETSTAT_MPTCPEXT_MPJOINSYNACKBACKUPRX,
+    _PM_NETSTAT_MPTCPEXT_MPCAPABLEENDPATTEMPT,
+    _PM_NETSTAT_MPTCPEXT_DSSCORRUPTIONFALLBACK,
+    _PM_NETSTAT_MPTCPEXT_DSSCORRUPTIONRESET,
 
     _PM_NETSTAT_MPTCPEXT_NFIELDS /* must be last */
 };
