@@ -1,40 +1,39 @@
 /*
  * Mailq PMDA
  *
+ * Copyright (c) 2012,2014,2022 Red Hat.
  * Copyright (c) 1997-2000,2003 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
 #include "pmapi.h"
-#include "impl.h"
 #include "pmda.h"
 #include "domain.h"
+#ifdef HAVE_REGEX_H
 #include <regex.h>
+#endif
 #include <sys/stat.h>
 
 /*
  * histogram for binning messages based on queue time
+ * (note that the 'delay' is also used as instance ID)
  */
 typedef struct {
     long	count;		/* number in this bin */
-    time_t	delay;		/* in queue for at least this long (seconds) */
+    unsigned int delay;		/* in queue for at least this long (seconds) */
 } histo_t;
 
-static histo_t	*histo = NULL;
-static int	numhisto = 0;
+static histo_t	*histo;
+static int	numhisto;
 static int	queue;
 
 /*
@@ -44,9 +43,10 @@ static pmdaInstid *_delay;
 
 static char	*queuedir = "/var/spool/mqueue";
 static char	startdir[MAXPATHLEN];
+static char	*username;
 
 static char	*regexstring;
-static regex_t	regex;
+static regex_t	mq_regex;
 
 /*
  * list of instance domains
@@ -70,7 +70,39 @@ static pmdaMetric metrictab[] = {
         PMDA_PMUNITS(0,0,1,0,0,PM_COUNT_ONE) }, },
 };
 
-static int compar(const void *a, const void *b)
+static int
+mailq_histogram(char *option)
+{
+    struct timeval	tv;
+    char		*errmsg;
+    char		*q;
+    unsigned int	instid;
+    int			sts;
+
+    q = strtok(option, ",");
+    while (q != NULL) {
+	if ((sts = pmParseInterval((const char *)q, &tv, &errmsg)) < 0) {
+	    pmprintf("%s: bad histogram bins argument:\n%s\n", pmGetProgname(), errmsg);
+	    free(errmsg);
+	    return -EINVAL;
+	}
+	if (tv.tv_sec >= UINT_MAX) {
+	    pmprintf("%s: bin size is too large (%lld):\n", pmGetProgname(), (long long)tv.tv_sec);
+	    return -EINVAL;
+	}
+	instid = (unsigned int)tv.tv_sec; /* Y2038-safe, size checked */
+	numhisto++;
+	histo = (histo_t *)realloc(histo, numhisto * sizeof(histo[0]));
+	if (histo == NULL)
+	    pmNoMem("histo", numhisto * sizeof(histo[0]), PM_FATAL_ERR);
+	histo[numhisto-1].delay = instid;
+	q = strtok(NULL, ",");
+    }
+    return 0;
+}
+
+static int
+compare_delay(const void *a, const void *b)
 {
     histo_t	*ha = (histo_t *)a;
     histo_t	*hb = (histo_t *)b;
@@ -84,17 +116,16 @@ static int compar(const void *a, const void *b)
 static int
 mailq_fetchCallBack(pmdaMetric *mdesc, unsigned int inst, pmAtomValue *atom)
 {
-    __pmID_int	*idp = (__pmID_int *)&(mdesc->m_desc.pmid);
     int		b;
 
-    if (idp->cluster == 0) {
-	if (idp->item == 0) {			/* mailq.length */
+    if (pmID_cluster(mdesc->m_desc.pmid) == 0) {
+	if (pmID_item(mdesc->m_desc.pmid) == 0) {	/* mailq.length */
 	    if (inst == PM_IN_NULL)
 		atom->ul = queue;
 	    else
 		return PM_ERR_INST;
 	}
-	else if (idp->item == 1) {		/* mailq.deferred */
+	else if (pmID_item(mdesc->m_desc.pmid) == 1) {	/* mailq.deferred */
 	    /* inst is unsigned, so always >= 0 */
 	    for (b = 0; b < numhisto; b++) {
 		if (histo[b].delay == inst) break;
@@ -142,14 +173,14 @@ mailq_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 
 	if (chdir(queuedir) < 0) {
 	    if (warn == 0) {
-		__pmNotifyErr(LOG_ERR, "chdir(\"%s\") failed: %s\n",
-		    queuedir, strerror(errno));
+		pmNotifyErr(LOG_ERR, "chdir(\"%s\") failed: %s\n",
+		    queuedir, osstrerror());
 		warn = 1;
 	    }
 	}
 	else {
 	    if (warn == 1) {
-		__pmNotifyErr(LOG_INFO, "chdir(\"%s\") success\n", queuedir);
+		pmNotifyErr(LOG_INFO, "chdir(\"%s\") success\n", queuedir);
 		warn = 0;
 	    }
 
@@ -158,18 +189,18 @@ mailq_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 	    for (i = 0; i < num; i++) {
 		p = list[i]->d_name;
 		/* only file names that match the regular expression */
-		if (regexstring && regexec(&regex, list[i]->d_name, 0, NULL, 0))
-		    goto next;
+		if (regexstring && regexec(&mq_regex, list[i]->d_name, 0, NULL, 0))
+		    continue;
 		else if (!regexstring && (*p != 'd' || *(p+1) != 'f'))
-		    goto next;
+		    continue;
 		if (stat(p, &sbuf) != 0) {
 		    /*
 		     * ENOENT expected sometimes if sendmail is doing its job
 		     */
-		    if (errno == ENOENT)
-			goto next;
-		    fprintf(stderr, "stat(\"%s\"): %s\n", p, strerror(errno));
-		    goto next;
+		    if (oserror() == ENOENT)
+			continue;
+		    fprintf(stderr, "stat(\"%s\"): %s\n", p, osstrerror());
+		    continue;
 		}
 		if (sbuf.st_size > 0 && S_ISREG(sbuf.st_mode)) {
 		    /* really in the queue */
@@ -188,14 +219,15 @@ mailq_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 		    }
 		    queue++;
 		}
-next:
-		free(list[i]);
 	    }
-	    free(list);
+	    for (i = 0; i < num; i++)
+		free(list[i]);
+	    if (num > 0)
+		free(list);
 	}
 	if (chdir(startdir) < 0) {
-	    __pmNotifyErr(LOG_ERR, "chdir(\"%s\") failed: %s\n",
-			startdir, strerror(errno));
+	    pmNotifyErr(LOG_ERR, "chdir(\"%s\") failed: %s\n",
+			startdir, osstrerror());
 	}
     }
 
@@ -211,107 +243,99 @@ mailq_init(pmdaInterface *dp)
     if (dp->status != 0)
 	return;
 
+    pmSetProcessIdentity(username);
     dp->version.two.fetch = mailq_fetch;
-
     pmdaSetFetchCallBack(dp, mailq_fetchCallBack);
-
     pmdaInit(dp, indomtab, sizeof(indomtab)/sizeof(indomtab[0]), metrictab,
 	     sizeof(metrictab)/sizeof(metrictab[0]));
 }
 
-static void
-usage(void)
-{
-    fprintf(stderr, "Usage: %s [options] [queuedir]\n\n", pmProgname);
-    fputs("Options:\n"
-	  "  -b binlist   times to be used for histogram bins as comma\n"
-	  "               separated values in pmParseInterval(3) format\n"
-	  "  -d domain    use domain (numeric) for metrics domain of PMDA\n"
-	  "  -l logfile   write log into logfile rather than using default log name\n"
-	  "  -r regex     regular expression for matching mail file names\n",
-	  stderr);		
-    exit(1);
-}
+pmdaInterface	dispatch;
+
+pmLongOptions	longopts[] = {
+    PMDA_OPTIONS_HEADER("Options"),
+    PMOPT_DEBUG,
+    { "binlist", 1, 'b', "TIMES", "comma-separated histogram bins times" },
+    PMDAOPT_DOMAIN,
+    PMDAOPT_LOGFILE,
+    { "regex", 1, 'r', "RE", "regular expression for matching mail file names" },
+    PMDAOPT_USERNAME,
+    PMOPT_HELP,
+    PMDA_OPTIONS_END
+};
+
+pmdaOptions	opts = {
+    .short_options = "b:D:d:l:r:U:?",
+    .long_options = longopts,
+    .short_usage = "[options] [queuedir]",
+};
 
 /*
- * Set up the agent if running as a daemon.
+ * Set up the agent, running as a daemon.
  */
 int
 main(int argc, char **argv)
 {
-    int			err = 0;
+    int			sep = pmPathSeparator();
     int			c;
-    int			sts;
     int			i;
-    time_t		tmp;
-    pmdaInterface	dispatch;
-    char		*q;
-    char		*errmsg;
+    unsigned int	tmp;
     char		namebuf[30];
-    struct timeval	tv;
     char		mypath[MAXPATHLEN];
 
-    __pmSetProgname(argv[0]);
-    getcwd(startdir, sizeof(startdir));
+    pmSetProgname(argv[0]);
+    pmGetUsername(&username);
 
-    snprintf(mypath, sizeof(mypath),
-		"%s/mailq/help", pmGetConfig("PCP_PMDAS_DIR"));
-    pmdaDaemon(&dispatch, PMDA_INTERFACE_2, pmProgname, MAILQ,
+    if (getcwd(startdir, sizeof(startdir)) == NULL) {
+	fprintf(stderr, "%s: getcwd() failed: %s\n",
+	    pmGetProgname(), pmErrStr(-oserror()));
+	exit(1);
+    }
+
+    pmsprintf(mypath, sizeof(mypath), "%s%c" "mailq" "%c" "help",
+		pmGetConfig("PCP_PMDAS_DIR"), sep, sep);
+    pmdaDaemon(&dispatch, PMDA_INTERFACE_2, pmGetProgname(), MAILQ,
 		"mailq.log", mypath);
 
-    while ((c = pmdaGetOpt(argc, argv, "b:D:d:l:r:?", &dispatch, &err)) != EOF) {
+    while ((c = pmdaGetOptions(argc, argv, &opts, &dispatch)) != EOF) {
 	switch (c) {
-	    case 'b':
-		q = strtok(optarg, ",");
-		while (q != NULL) {
-		    sts = pmParseInterval((const char *)q, &tv, &errmsg);
-		    if (sts < 0) {
-			fprintf(stderr, "%s: bad -b argument:\n%s\n",
-			    pmProgname, errmsg);
-			err++;
-		    }
-		    numhisto++;
-		    histo = (histo_t *)realloc(histo, numhisto * sizeof(histo[0]));
-		    if (histo == NULL) {
-			 __pmNoMem("histo", numhisto * sizeof(histo[0]), PM_FATAL_ERR);
-		    }
-		    histo[numhisto-1].delay = tv.tv_sec;
-		    q = strtok(NULL, ",");
-		}
-		break;
+	case 'b':
+	    if (mailq_histogram(opts.optarg) < 0)
+		opts.errors++;
+	    break;
 
-	    case 'r':
-		regexstring = optarg;
-		c = regcomp(&regex, regexstring, REG_EXTENDED | REG_NOSUB);
-		if (c != 0) {
-		    regerror(c, &regex, mypath, sizeof(mypath));
-		    fprintf(stderr, "Cannot compile regular expression: %s\n",
-				    mypath);
-		    exit(1);
-		}
-		break;
-
-	    default:
-		err++;
-		break;
+	case 'r':
+	    regexstring = opts.optarg;
+	    c = regcomp(&mq_regex, regexstring, REG_EXTENDED | REG_NOSUB);
+	    if (c != 0) {
+		regerror(c, &mq_regex, mypath, sizeof(mypath));
+		pmprintf("%s: cannot compile regular expression: %s\n",
+			pmGetProgname(), mypath);
+		opts.errors++;
+	    }
+	    break;
 	}
     }
 
-    if (optind == argc-1)
-	queuedir = argv[optind];
-    else if (optind != argc)
-	err++;
+    if (opts.optind == argc - 1)
+	queuedir = argv[opts.optind];
+    else if (opts.optind != argc)
+	opts.errors++;
 
-    if (err) {
-    	usage();
+    if (opts.errors) {
+	pmdaUsageMessage(&opts);
+	exit(1);
     }
 
+    if (opts.username)
+	username = opts.username;
+
     if (histo == NULL) {
 	/* default histo bins, if not already done above ... */
 	numhisto = 7;
 	histo = (histo_t *)malloc(numhisto * sizeof(histo[0]));
 	if (histo == NULL) {
-	     __pmNoMem("histo", numhisto * sizeof(histo[0]), PM_FATAL_ERR);
+	     pmNoMem("histo", numhisto * sizeof(histo[0]), PM_FATAL_ERR);
 	}
 	histo[0].delay = 7 * 24 * 3600;
 	histo[1].delay = 3 * 24 * 3600;
@@ -326,47 +350,47 @@ main(int argc, char **argv)
 	numhisto++;
 	histo = (histo_t *)realloc(histo, numhisto * sizeof(histo[0]));
 	if (histo == NULL) {
-	     __pmNoMem("histo", numhisto * sizeof(histo[0]), PM_FATAL_ERR);
+	     pmNoMem("histo", numhisto * sizeof(histo[0]), PM_FATAL_ERR);
 	}
 	histo[numhisto-1].delay = 0;
-	qsort(histo, numhisto, sizeof(histo[0]), compar);
+	qsort(histo, numhisto, sizeof(histo[0]), compare_delay);
     }
 
     _delay = (pmdaInstid *)malloc(numhisto * sizeof(_delay[0]));
-    if (_delay == NULL) {
-	 __pmNoMem("_delay", numhisto * sizeof(_delay[0]), PM_FATAL_ERR);
-    }
+    if (_delay == NULL)
+	pmNoMem("_delay", numhisto * sizeof(_delay[0]), PM_FATAL_ERR);
+
     for (i = 0; i < numhisto; i++) {
 	_delay[i].i_inst = histo[i].delay;
 	histo[i].count = 0;
 	if (histo[i].delay == 0)
-	    sprintf(namebuf, "recent");
+	    pmsprintf(namebuf, sizeof(namebuf), "recent");
 	else if (histo[i].delay < 60)
-	    sprintf(namebuf, "%d-secs", (int)histo[i].delay);
+	    pmsprintf(namebuf, sizeof(namebuf), "%u-secs", histo[i].delay);
 	else if (histo[i].delay < 60 * 60) {
 	    tmp = histo[i].delay / 60;
 	    if (tmp <= 1)
-		sprintf(namebuf, "1-min");
+		pmsprintf(namebuf, sizeof(namebuf), "1-min");
 	    else
-		sprintf(namebuf, "%d-mins", (int)tmp);
+		pmsprintf(namebuf, sizeof(namebuf), "%u-mins", tmp);
 	}
 	else if (histo[i].delay < 24 * 60 * 60) {
 	    tmp = histo[i].delay / (60 * 60);
 	    if (tmp <= 1)
-		sprintf(namebuf, "1-hour");
+		pmsprintf(namebuf, sizeof(namebuf), "1-hour");
 	    else
-		sprintf(namebuf, "%d-hours", (int)tmp);
+		pmsprintf(namebuf, sizeof(namebuf), "%u-hours", tmp);
 	}
 	else {
 	    tmp = histo[i].delay / (24 * 60 * 60);
 	    if (tmp <= 1)
-		sprintf(namebuf, "1-day");
+		pmsprintf(namebuf, sizeof(namebuf), "1-day");
 	    else
-		sprintf(namebuf, "%d-days", (int)tmp);
+		pmsprintf(namebuf, sizeof(namebuf), "%u-days", tmp);
 	}
 	_delay[i].i_name = strdup(namebuf);
 	if (_delay[i].i_name == NULL) {
-	     __pmNoMem("_delay[i].i_name", strlen(namebuf), PM_FATAL_ERR);
+	     pmNoMem("_delay[i].i_name", strlen(namebuf), PM_FATAL_ERR);
 	}
     }
 
