@@ -1,5 +1,5 @@
 /*
- * utils for pmlogextract
+ * utils for pmlogreduce
  *
  * Copyright (c) 2017 Red Hat.
  * Copyright (c) 1997-2002 Silicon Graphics, Inc.  All Rights Reserved.
@@ -17,25 +17,6 @@
 
 #include "pmlogreduce.h"
 
-int
-_pmLogPut(__pmFILE *f, __pmPDU *pb)
-{
-    int		rlen = ntohl(pb[0]);
-    int		sts;
-
-    if (pmDebugOptions.log) {
-	fprintf(stderr, "_pmLogPut: fd=%d rlen=%d\n",
-	    __pmFileno(f), rlen);
-    }
-
-    if ((sts = (int)__pmFwrite(pb, 1, rlen, f)) != rlen) {
-	if (pmDebugOptions.log)
-	    fprintf(stderr, "_pmLogPut: fwrite=%d %s\n", sts, osstrerror());
-	return -oserror();
-    }
-    return 0;
-}
-
 /*
  * construct new external label, and check label records from
  * input archives
@@ -46,20 +27,12 @@ newlabel(void)
     __pmLogLabel	*lp = &logctl.label;
 
     /* check version number */
-#ifdef __PCP_EXPERIMENTAL_ARCHIVE_VERSION3
     if ((ilabel.ll_magic & 0xff) != PM_LOG_VERS02 &&
         (ilabel.ll_magic & 0xff) != PM_LOG_VERS03) {
 	fprintf(stderr,"%s: Error: version number %d (not %d or %d as expected) in archive (%s)\n",
 		pmGetProgname(), ilabel.ll_magic & 0xff, PM_LOG_VERS02, PM_LOG_VERS03, iname);
 	exit(1);
     }
-#else
-    if ((ilabel.ll_magic & 0xff) != PM_LOG_VERS02) {
-	fprintf(stderr,"%s: Error: version number %d (not %d as expected) in archive (%s)\n",
-		pmGetProgname(), ilabel.ll_magic & 0xff, PM_LOG_VERS02, iname);
-	exit(1);
-    }
-#endif
 
     /* copy magic number, host and timezone info, use our pid */
     lp->magic = ilabel.ll_magic;
