@@ -171,7 +171,7 @@ void readSettings(void)
 
     globalSettings.gridBackgroundModified = false;
     globalSettings.gridBackgroundName = userSettings.value(
-		"gridBackgroundColor", "rgbi:0.15/0.15/0.15").toString();
+		"gridBackgroundColor", "#262626").toString(); // rgbi:0.15/0.15/0.15
     globalSettings.gridBackground = QColor(globalSettings.gridBackgroundName);
 
     //
@@ -234,9 +234,10 @@ genInventor(void)
 	if (fd < 0) goto fail;
 	if (!(theAltConfig = fdopen(fd, "a")))
 fail:
-            pmprintf("%s: Warning: Unable to save configuration for"
+	    pmprintf("%s: Warning: Unable to save configuration for"
 	             "recording to \"%s\": %s\n",
-		    pmGetProgname(), configfile, strerror(errno));
+		    pmGetProgname(), configfile == NULL ? "???" : configfile,
+		    strerror(errno));
 	else if (pmDebugOptions.appl0)
 	    cerr << "genInventor: Copy of configuration saved to "
 		 << configfile << Qt::endl;
@@ -254,6 +255,9 @@ fail:
 	     << theConfigName << Qt::endl;
     }
 
+    if (warnCount > 0)
+	pmflush();
+
     sts = -errorCount;
 
     if (rootObj != NULL) {
@@ -341,6 +345,7 @@ main(int argc, char **argv)
     }
 
     a.startconsole();
+    console->setWindowTitle(QCoreApplication::translate("Console", "pmview Console", nullptr));
 
     if (a.my.archives.size() > 0)
 	while (optind < argc)
