@@ -24,6 +24,8 @@
 **                                                                        **
 \**************************************************************************/
 #define PY_SSIZE_T_CLEAN
+#define _FILE_OFFSET_BITS 64
+#define _TIME_BITS 64
 #include <Python.h>
 #define PMAPI_VERSION 3
 #include <pcp/pmapi.h>
