@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015,2017-2021 Red Hat.
+ * Copyright (C) 2013-2015,2017-2021,2024 Red Hat.
  *
  * This file is part of the "pcp" module, the python interfaces for the
  * Performance Co-Pilot toolkit.
@@ -21,6 +21,8 @@
  * python PMDAs via the pmda.py module, using ctypes.
  */
 #define PY_SSIZE_T_CLEAN
+#define _FILE_OFFSET_BITS 64
+#define _TIME_BITS 64
 #include <Python.h>
 #include <pcp/pmapi.h>
 #include <pcp/pmda.h>
@@ -940,6 +942,9 @@ endContextCallBack(int ctx)
 static inline int
 pmda_generating_pmns(void) { return getenv("PCP_PYTHON_PMNS") != NULL; }
 
+static inline int
+pmda_probing_domain(void) { return getenv("PCP_PYTHON_PROBE") != NULL; }
+
 static inline int
 pmda_generating_domain(void) { return getenv("PCP_PYTHON_DOMAIN") != NULL; }
 
@@ -984,7 +989,7 @@ init_dispatch(PyObject *self, PyObject *args, PyObject *keywords)
     pmdaSetFetchCallBack(&dispatch, fetch_callback);
     pmdaSetEndContextCallBack(&dispatch, endContextCallBack);
 
-    if (!pmda_generating_pmns() && !pmda_generating_domain())
+    if (!pmda_generating_pmns() && !pmda_generating_domain() && !pmda_probing_domain())
 	pmdaOpenLog(&dispatch);
 
     Py_INCREF(Py_None);
@@ -1003,7 +1008,7 @@ connect_pmcd(void)
      * channel setup and complete the connection handshake with
      * pmcd.
      */
-    if (!pmda_generating_pmns() && !pmda_generating_domain()) {
+    if (!pmda_generating_pmns() && !pmda_generating_domain() && !pmda_probing_domain()) {
 	/*
 	 * On success pmdaConnect sets PMDA_EXT_CONNECTED in e_flags ...
 	 * this used in the guard below to stop pmda_dispatch() calling
